-- This file is a part of Falling Block Game 2.
-- 
-- Copyright (C) 2010 Jared Krinke.
-- 
-- Falling Block Game 2 is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("UI/UI.lua")
require("Diagnostics/LogDisplay.lua")

-- Console layer
local consoleColumns = 80
local consoleRows = 25
-- TODO: Need some way to determine the screen's dimensions
local consoleWidth = 640
local consoleHeight = 480

Console = { }

Console.State = consoleState

function Console.new()
    local consoleForm = Form.newGrid(1, -consoleWidth / 2, consoleHeight / 2, consoleWidth, consoleHeight)

    consoleForm:add(LogDisplay.new(consoleRows - 1, true))
    consoleForm:add(TextInputBox.new(function(self)
        local command = self.buffer.text
    
        self:clear()
        print(command)
        execute(command)
    end))

    -- TODO: Add a background? Or animation?
    consoleForm:setTextSize(consoleWidth / consoleColumns, consoleHeight / consoleRows)
    consoleForm:layout()

    consoleForm.inputReceivedBase = consoleForm.inputReceived

    consoleForm.inputReceived = function(self, event, pressed)
        local handled = false

        if event == "openConsole" then
            if pressed then
                Layers.pop()
            end

            handled = true
        else
            handled = consoleForm:inputReceivedBase(event, pressed)
        end

        return handled
    end

    return FormLayer.new(consoleForm)
end

