-- This file is a part of Falling Block Game 2.
-- 
-- Copyright (C) 2010 Jared Krinke.
-- 
-- Falling Block Game 2 is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
-- 
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
-- 
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

require("UI/UI.lua")
require("UI/Input.lua") -- TODO: Should this go in UI.lua?
require("UI/Control.lua") -- TODO: Should this go in UI.lua?
require("Utility/ForEach.lua")
require("Utility/SortedList.lua")
require("Utility/List.lua")

local logicalEvents = {
    "up",
    "down",
    "left",
    "right",
    "rotateLeft",
    "rotateRight",
    "activate",
    "delete",
    "cancel",
}

local logicalEventNames = {
    up = "Menu Up/Rotate",
    down = "Menu Down/Drop",
    left = "Move Left",
    right = "Move Right",
    rotateLeft = "Rotate Left",
    rotateRight = "Rotate Right",
    activate = "Activate",
    delete = "Delete",
    cancel = "Cancel",
}

Controls = { }

function Controls.save()
    File.createDirectory("Settings")

    local file = File.openWrite("Settings/Controls.lua")

    file:write("controlsData = {")

    Table.forEach(Fbg2.input:getRawToLogical(), function(rawEvent, logicalEvent)
        -- TODO: Add utility function like formatAsTableKey (converting key to key, " to ["\""], \ to ["\\"], etc.
        if rawEvent ~= "\\" then
            file:write("    [\"" .. rawEvent .. "\"] = \"" .. logicalEvent .. "\",")
        else
            file:write("    [\"\\\"] = \"" .. logicalEvent .. "\",")
        end
    end)

    file:write("}")
    file:close()
end

Fbg2.input:addListener(Controls.save)

-- Controls menu
ControlsMenu = { }

function ControlsMenu.new()
    local controlsForm = Form.newGrid(1, Fbg2.formX, Fbg2.formY, Fbg2.formWidth)

    -- UI
    controlsForm:add(Title.new("Controls"))
    controlsForm:add(Separator.new())

    -- Add controls
    local i = 1

    while not isNil(logicalEvents[i]) do
        local logicalEvent = logicalEvents[i]

        controlsForm:add(Control.new(Fbg2.input, logicalEvent, logicalEventNames[logicalEvent]))
        i = i + 1
    end

    -- TODO: Focus-able area on the back button spans the entire grid and
    -- there's no way to fix this without laying out components differently
    -- in the same form
    controlsForm:add(Separator.new())
    controlsForm:add(Button.new("Back", function() Layers.pop() end))

    return FormLayer.new(controlsForm)
end

